# Examples displaying capabilities of ComiQ
### 1. Comic Image, with normal, horizontal oriented text, and no background text.
![preview](https://github.com/StoneSteel27/ComiQ/blob/main/examples/images/normal-text--normal-orientation.png)
### 2. Comic Image, with normal, horizontal oriented text, and with background text.
![preview](https://github.com/StoneSteel27/ComiQ/blob/main/examples/images/normal-text--with-bg-text.png)
### 3. Comic Image, with styled, horizontal oriented text, and with background text.
![preview](https://github.com/StoneSteel27/ComiQ/blob/main/examples/images/styled-text--with-bg-text.png)
### 4. Comic Image, with styled, vertical oriented, and with background text.
![preview](https://github.com/StoneSteel27/ComiQ/blob/main/examples/images/styled-text--vertical-orientation--with-bg-text.png)
### 5. Comic Image, with handwriting text, with background text.
![preview](https://github.com/StoneSteel27/ComiQ/blob/main/examples/images/handwriting--with-bg-text.png)
